Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrJoinFailed is returned when a node fails to join a cluster ErrJoinFailed = errors.New("failed to join cluster") )
Functions ¶
func Join ¶
func Join(srcIP string, joinAddr []string, id, addr string, voter bool, meta map[string]string, numAttempts int, attemptInterval time.Duration, tlsConfig *tls.Config, authConfig auth.AuthConfig) (string, error)
Join attempts to join the cluster at one of the addresses given in joinAddr. It walks through joinAddr in order, and sets the node ID and Raft address of the joining node as id addr respectively. It returns the endpoint successfully used to join the cluster.
Types ¶
type Listener ¶
Listener handles the connection of multiple net.Listener, provides listening and accepting new connection.
Click to show internal directories.
Click to hide internal directories.